package com.ruoyi.web.system.controller;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.model.LoginBody;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.framework.web.service.SysLoginService;
import com.ruoyi.framework.web.service.TokenService;
import com.ruoyi.web.system.service.IWechatUserLoginService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @version : V1.0
 * @ClassName: LoginController
 * @Description: 用户登录
 * @Auther: JiangYuQi
 * @Date: 2020/7/7 18:03
 */
@RestController
@RequestMapping("/wechat")
public class WechatUserLoginController extends BaseController {

    @Autowired
    private SysLoginService loginService;

    @Autowired
    private TokenService tokenService;

    @Autowired
    private IWechatUserLoginService wechatUserLoginService;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), null,
                null);
        ajax.put(Constants.TOKEN, token);
        ajax.put("data",wechatUserLoginService.findUserInfo(loginBody.getUsername(),loginBody.getOpenId()));
        return ajax;
    }


    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/openIdLogin")
    public AjaxResult openIdLogin(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        LoginUser loginUser = wechatUserLoginService.getLoginUserByOpenId(loginBody.getOpenId());
        if(loginUser!=null){
            // 生成令牌
            String token = tokenService.createToken(loginUser);
            ajax.put(Constants.TOKEN, token);
            ajax.put("data",wechatUserLoginService.findUserInfo(loginUser.getUsername(),loginBody.getOpenId()));
        }else{
            return error();
        }
        return ajax;
    }

    /**
     * 查询出openid
     * @param code
     * @param appId
     * @return
     */
    @GetMapping("/getOpenId")
    public Object getOpenId(String code,String appId){
        return wechatUserLoginService.getOpenId(code,appId);
    }

    /**
     * 根据用户查询菜单信息
     * @param username
     * @return
     */
    @GetMapping("/selectRoleMenuList")
    public Object selectRoleMenuList(String username){
        return wechatUserLoginService.selectRoleMenuList(username);
    }

}
