package com.ruoyi.web.system.service.impl;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.DeptTypeEnum;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.framework.web.service.SysPermissionService;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.web.system.mapper.WechatUserLoginMapper;
import com.ruoyi.web.system.service.IWechatUserLoginService;
import com.yanzhu.jh.project.domain.SurProject;
import com.yanzhu.jh.project.mapper.SurProjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @version : V1.0
 * @ClassName: WechatUserLoginServiceImpl
 * @Description: 微信用户登录
 * @Auther: JiangYuQi
 * @Date: 2020/7/7 18:03
 */
@Service
public class WechatUserLoginServiceImpl implements IWechatUserLoginService {

    private static Map<String,String>appInfo  = new HashMap<>();

    static {
        //产发数字系统
        appInfo.put("wxc44b5d588f599758","b4da7402397f559395db7c1b0534c369");
    }

    @Autowired
    private ISysUserService userService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private SysDeptMapper sysDeptMapper;

    @Autowired
    private SurProjectMapper surProjectMapper;

    @Autowired
    private WechatUserLoginMapper wechatUserLoginMapper;

    /**
     * 获取用户信息
     * @param loginName
     * @return
     */
    @Override
    public Map<String, Object> findUserInfo(String loginName,String openId) {
        Map<String,Object> data = new HashMap<>();
        Map<String, Object> userData = wechatUserLoginMapper.findUserInfo(loginName);
        Map<String,Object> userInfo = new HashMap<>();
        userInfo.put("loginName",loginName);
        userInfo.put("userName",userData.get("user_name"));
        userInfo.put("nickName",userData.get("nick_name"));
        userInfo.put("deptName",userData.get("dept_name"));
        userInfo.put("deptId",userData.get("dept_id"));
        userInfo.put("userId",userData.get("user_id"));
        userInfo.put("remark",userData.containsKey("remark")?userData.get("remark"):"");
        userInfo.put("roleId",userData.get("roleId"));
        userInfo.put("roleName",userData.get("roleName"));
        /** 查询当前用户项目信息 **/

        SurProject surProject = new SurProject();
        String nowRole = Convert.toStr(userData.get("minRoleId"));
        if(SysRoleEnum.ZGS.getCode().equals(nowRole)){
            Long deptId = this.getZgsDept(Convert.toLong(userData.get("dept_id"))).getDeptId();
            surProject.setNowDept(Convert.toStr(deptId));
        }else{
            surProject.setNowDept(Convert.toStr(userData.get("dept_id")));
        }
        //当前角色时管理员时，修改角色为集团公司
        if(Convert.toInt(SysRoleEnum.JTGS.getCode())>Convert.toInt(nowRole)){
            nowRole = SysRoleEnum.JTGS.getCode();
        }
        surProject.setNowRole(nowRole);
        surProject.setNowUser(Convert.toStr(userData.get("user_id")));
        List<SurProject> projectList  = surProjectMapper.selectSurProjectList(surProject);
        //只有一个项目时直接保存项目信息
        if(projectList!=null && projectList.size()==1){
            Map<String,Object> projectInfo = new HashMap<>();
            projectInfo.put("projectId",projectList.get(0).getId());
            projectInfo.put("projectName",projectList.get(0).getProjectName());
            projectInfo.put("projectInfoList",projectList);
            projectInfo.put("shengName","西安市");
            projectInfo.put("shiName","西咸新区");
            projectInfo.put("quName","泾河新城");
            projectInfo.put("logCompanyName",userData.get("dept_name"));
            data.put("projectInfo",projectInfo);
        }
        data.put("userinfo",userInfo);
        //存储用户openid
        Map<String,Object> map = new HashMap<>();
        map.put("loginName",loginName);
        map.put("userId", Convert.toStr(userData.get("user_id")));
        map.put("nickname",userData.get("nick_name"));
        map.put("openId",openId);
        //验证手机号码是否绑定
        int count = wechatUserLoginMapper.checkBindByOpenId(openId);
        if(count > 0){
            wechatUserLoginMapper.updateUserOpenId(map);
        }else {
            wechatUserLoginMapper.addUserOpenId(map);
        }
        return data;
    }

    /**
     * 根据openId查询用户认证对象
     * @param openId
     * @return
     */
    public LoginUser getLoginUserByOpenId(String openId) {
        Map<String,Object> userMap = wechatUserLoginMapper.getUserNameByOpenId(openId);
        if(userMap!=null){
            SysUser user = userService.selectUserByUserName(Convert.toStr(userMap.get("loginName")));
            return new LoginUser(user.getUserId(), user.getDeptId(), user, permissionService.getMenuPermission(user));
        }
        return null;
    }

    /**
     * 查询子公司部门ID
     *
     * @param deptId 部门ID
     * @return 结果
     */
    private SysDept getZgsDept(Long deptId){
        SysDept sysDept = sysDeptMapper.selectDeptById(deptId);
        if(DeptTypeEnum.ZGS.getCode().equals(sysDept.getTypeFlag())){
            //comFlag标识为1是子公司
            if(DeptTypeEnum.COMFLAG.getCode().equals(sysDept.getComFlag())){
                return sysDept;
            }else{
                return getZgsDept(sysDept.getParentId());
            }
        }else{
            return sysDept;
        }
    }

    @Override
    public Map<String, Object> getOpenId(String code, String appId) {
        String url = "https://api.weixin.qq.com/sns/jscode2session?appid="+appId+"&secret="+appInfo.get(appId)+"&js_code="+code+"&grant_type=authorization_code";
        String resultStr = HttpUtil.get(url);
        JSONObject json = JSONObject.parseObject(resultStr);
        //删除参数session_key，否则小程序检测关键参数暴露，提示整改
        json.remove("session_key");
        return json;
    }

    /**
     * 根据用户查询菜单信息
     * @param username
     * @return
     */
    @Override
    public List<Map<String,Object>> selectRoleMenuList(String username) {
        return wechatUserLoginMapper.selectRoleMenuList(username);
    }

}
