package com.ruoyi.web.userLogin.service;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.DeptTypeEnum;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.ip.IpUtils;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.mapper.SysRoleMapper;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.system.service.ISysConfigService;
import com.ruoyi.web.projectInfo.mapper.WxProjectInfoMapper;
import com.ruoyi.web.userLogin.mapper.WxUserLoginMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpSession;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class WxUserLoginServiceImpl implements WxUserLoginService{
    private static Map<String,String>appInfo  = new HashMap<>();
    static {
        //智慧工地优管
        appInfo.put("wx23d12da8a7e50906","8438a009f433fb7fc8e8d4681d24d718");
        //产发数字系统
        appInfo.put("wxc44b5d588f599758","b4da7402397f559395db7c1b0534c369");
    }

    @Autowired
    private ISysConfigService configService;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private WxUserLoginMapper mapper;

    @Autowired
    private SysDeptMapper sysDeptMapper;

    @Autowired
    private SysRoleMapper sysRoleMapper;

    @Autowired
    private WxProjectInfoMapper ProjectInfoMapper;

    @Override
    public Map<String,Object> checkLogoin(String loginName, String password,String openId, HttpSession session) {
        Map<String,Object> stateMap = new HashMap<>();
        Map<String,Object> map = new HashMap<>();
        map.put("loginName",loginName);
        // 用户名不在指定范围内 错误
        if (loginName.length() != UserConstants.PHONE_LENGTH)
        {
            stateMap.put("data","300");
            stateMap.put("info","账号错误，请您重新输入");
        }
        // 密码如果不在指定范围内 错误
        if (password.length() < UserConstants.PASSWORD_MIN_LENGTH
                || password.length() > UserConstants.PASSWORD_MAX_LENGTH)
        {
            stateMap.put("data","300");
            stateMap.put("info","密码错误，请您重新输入");
        }
        // IP黑名单校验
        String blackStr = configService.selectConfigByKey("sys.login.blackIPList");
        if (IpUtils.isMatchedIp(blackStr, IpUtils.getIpAddr()))
        {
            stateMap.put("data","300");
            stateMap.put("info","当前登录IP未在白名单，请您联系系统供应商");
        }
        Map<String,Object> userMap =  mapper.checkLoginNameAndPsw(map);
        if(userMap == null){
            stateMap.put("data","300");
            stateMap.put("info","账号不存在，请您重新输入");
        }else {
            if(!SecurityUtils.matchesPassword(password,userMap.get("password").toString())){
                stateMap.put("data","300");
                stateMap.put("info","密码错误，请您重新输入");
            }else {
                Map<String,Object> userInfo = new HashMap<>();
                userInfo.put("loginName",loginName);
                userInfo.put("userName",userMap.get("user_name"));
                userInfo.put("nickName",userMap.get("nick_name"));
                userInfo.put("deptName",userMap.get("dept_name"));
                userInfo.put("deptId",userMap.get("dept_id"));
                userInfo.put("userId",userMap.get("user_id"));
                userInfo.put("remark",userMap.containsKey("remark")?userMap.get("remark"):"");
                userInfo.put("roleId",userMap.get("roleId"));
                userInfo.put("roleName",userMap.get("roleName"));
                //存数据到session
                session.setAttribute("userInfo",userInfo);
                //设置缓存时间为一天
                session.setMaxInactiveInterval(60*60*24);
                /** 查询当前用户项目信息 **/
                //当前登录账号角色信息
                String nowRole = Convert.toStr(sysRoleMapper.getUserMinRoleId(Convert.toLong(userMap.get("user_id"))));
                if(SysRoleEnum.ZGS.getCode().equals(nowRole)){
                    Long deptId = this.getZgsDept(Convert.toLong(userMap.get("dept_id"))).getDeptId();
                    map.put("nowDeptId",Convert.toStr(deptId));
                }else{
                    map.put("nowDeptId",Convert.toStr(userMap.get("dept_id")));
                }
                //当前角色时管理员时，修改角色为集团公司
                if(Convert.toInt(SysRoleEnum.JTGS.getCode())>Convert.toInt(nowRole)){
                    nowRole = SysRoleEnum.JTGS.getCode();
                }
                map.put("nowRole",nowRole);
                List<Map<String, Object>> projectList  = ProjectInfoMapper.getProjectByDeptIdAndCompanyId(map);
                stateMap.put("data","200");
                stateMap.put("info","登录成功");
                stateMap.put("userinfo",userInfo);
                //只有一个项目时直接保存项目信息
                if(projectList!=null && projectList.size()==1){
                    Map<String,Object> projectInfo = new HashMap<>();
                    projectInfo.put("projectId",projectList.get(0).get("projectId"));
                    projectInfo.put("projectName",projectList.get(0).get("projectName"));
                    projectInfo.put("projectInfoList",projectList);
                    projectInfo.put("shengName","西安市");
                    projectInfo.put("shiName","西咸新区");
                    projectInfo.put("quName","泾河新城");
                    projectInfo.put("logCompanyName",userMap.get("dept_name"));
                    stateMap.put("projectInfo",projectInfo);
                }
                //存储用户openid
                map.put("userId", Convert.toStr(userMap.get("user_id")));
                map.put("nickname",userMap.get("nick_name"));
                map.put("openId",openId);
                //验证手机号码是否绑定
                int count = mapper.checkBindByOpenId(openId);
                if(count > 0){
                    mapper.updateUserOpenId(map);
                }else {
                    mapper.addUserOpenId(map);
                }
            }
        }
        return stateMap;
    }

    @Override
    public Map<String,Object> updataUser(Map<String, Object> map) {
        Map<String,Object> infoMap = new HashMap<>();
        String oldPws = Convert.toStr(map.get("oldPsw"));
        SysUser sysUser = sysUserMapper.selectUserByUserName(Convert.toStr(map.get("loginName")));
        if(!SecurityUtils.matchesPassword(oldPws,sysUser.getPassword())) {
            infoMap.put("data","-1");
            infoMap.put("info","旧密码错误，请重新输入！");
            return infoMap;
        }
        if(!Convert.toStr(map.get("newPsw")).equals(Convert.toStr(map.get("password")))){
            infoMap.put("data","-2");
            infoMap.put("info","两次密码不一致，请重新输入！");
            return infoMap;
        }
        map.put("password",SecurityUtils.encryptPassword(Convert.toStr(map.get("password"))));
        if(mapper.updataUser(map) > 0){
            infoMap.put("data","200");
            infoMap.put("info","操作成功");
        }else {
            infoMap.put("data","-3");
            infoMap.put("info","操作失败！");
        }
        return infoMap;
    }

    @Override
    public Map<String,Object> addUserOpenId(Map<String, Object> map) {
        Map<String,Object> dataMap = new HashMap<>(16);
        String userId =mapper.getUserIdByPhone(map.get("loginName").toString());
        if(StringUtils.isNotBlank(userId)){
            map.put("userId",userId);
            if(mapper.addUserOpenId(map)>0){
                dataMap.put("code","200");
                dataMap.put("msg","添加成功");
            }else {
                dataMap.put("code","300");
                dataMap.put("msg","添加失败");
            }
        }else {
            dataMap.put("code","300");
            dataMap.put("msg","添加失败,userId为空");
        }
        return dataMap;
    }

    @Override
    public Map<String, Object> getUserInfoByOpenId(String openId, HttpSession session) {
        Map<String,Object> map = new HashMap<>(16);
        Map<String,Object> dataMap = mapper.getUserInfoByOpenId(openId);
        if(dataMap != null){
            map.put("code","200");
            map.put("userinfo",dataMap);
            map.put("info","登录成功");
            //存数据到session
            session.setAttribute("userInfo",dataMap);
            //设置缓存时间为一天
            session.setMaxInactiveInterval(60*60*24);

            /** 查询当前用户项目信息 **/
            Map<String,Object> searchMap = new HashMap<>(16);
            //当前登录账号角色信息
            String nowRole = Convert.toStr(sysRoleMapper.getUserMinRoleId(Convert.toLong(dataMap.get("userId"))));
            if(SysRoleEnum.ZGS.getCode().equals(nowRole)){
                Long deptId = this.getZgsDept(Convert.toLong(dataMap.get("deptId"))).getDeptId();
                searchMap.put("nowDeptId",Convert.toStr(deptId));
            }else{
                searchMap.put("nowDeptId",Convert.toStr(dataMap.get("deptId")));
            }
            //当前角色时管理员时，修改角色为集团公司
            if(Convert.toInt(SysRoleEnum.JTGS.getCode())>Convert.toInt(nowRole)){
                nowRole = SysRoleEnum.JTGS.getCode();
            }
            searchMap.put("nowRole",nowRole);
            searchMap.put("userId",dataMap.get("userId"));
            List<Map<String, Object>> projectList  = ProjectInfoMapper.getProjectByDeptIdAndCompanyId(searchMap);
            //只有一个项目时直接保存项目信息
            if(projectList!=null && projectList.size()==1){
                Map<String,Object> projectInfo = new HashMap<>();
                projectInfo.put("projectId",projectList.get(0).get("projectId"));
                projectInfo.put("projectName",projectList.get(0).get("projectName"));
                projectInfo.put("projectInfoList",projectList);
                projectInfo.put("shengName","西安市");
                projectInfo.put("shiName","西咸新区");
                projectInfo.put("quName","泾河新城");
                projectInfo.put("logCompanyName",dataMap.get("deptName"));
                map.put("projectInfo",projectInfo);
            }
        }else {
            map.put("code","300");
            map.put("msg","暂无数据");
        }
        return map;
    }

    @Override
    public Map<String, Object> checkBindByPhone(String phone) {
        Map<String,Object> map = new HashMap<>(16);
        int count = mapper.checkBindByPhone(phone);
        if(count >0){
            map.put("code","300");
            map.put("msg","该号码已绑定,请重新输入！");
        }else {
            map.put("code","200");
            map.put("msg","验证成功");
        }
        return map;
    }

    @Override
    public Map<String, Object> selectMenuList() {
        Map<String,Object> map = new HashMap<>(16);
        List<Map<String,Object>> list = mapper.selectMenuList();
        if(list != null && list.size() > 0){
            map.put("code","200");
            map.put("data",list);
            map.put("msg","查询成功");
        }else {
            map.put("code","300");
            map.put("msg","查询失败");
        }
        return map;
    }

    /**
     * 查询子公司部门ID
     *
     * @param deptId 部门ID
     * @return 结果
     */
    private SysDept getZgsDept(Long deptId){
        SysDept sysDept = sysDeptMapper.selectDeptById(deptId);
        if(DeptTypeEnum.ZGS.getCode().equals(sysDept.getTypeFlag())){
            //comFlag标识为1是子公司
            if(DeptTypeEnum.COMFLAG.getCode().equals(sysDept.getComFlag())){
                return sysDept;
            }else{
                return getZgsDept(sysDept.getParentId());
            }
        }else{
            return sysDept;
        }
    }

    @Override
    public Map<String, Object> getOpenId(String code, String appId) {
        String url = "https://api.weixin.qq.com/sns/jscode2session?appid="+appId+"&secret="+appInfo.get(appId)+"&js_code="+code+"&grant_type=authorization_code";
        String resultStr = HttpUtil.get(url);
        JSONObject json = JSONObject.parseObject(resultStr);
        //删除参数session_key，否则小程序检测关键参数暴露，提示整改
        json.remove("session_key");
        return json;
    }
}
